/*
*********************************************************************************************************
*                                               uC/OS-II
*                                         The Real-Time Kernel
*
*                         (c) Copyright 1998, Jean J. Labrosse, Plantation, FL
*                                          All Rights Reserved
*
*
*                                          MC68HC912BC32 Sample code
*
* File : TEST.C
* By   : R.C. Maher
*********************************************************************************************************
*/
#include <hidef.h>         /* common defines and macros                     */
#include <MC68HC912BC32.h> /* derivative information                        */
#include "dbug12.h"			   /* DBug-12 references (not used in this example) */
#include "INCLUDES.H"		   /* Includes all the uC/OS-II material            */

#define TASK_STK_SIZE 128	 /* Stack size of each task (modify if necessary) */



OS_STK taskstack1[TASK_STK_SIZE];  /* Declare stack for the myTask1 task    */


/*
*********************************************************************************************************
*                                                myTask1()
*
* Description : Example task to wait 2 seconds, then toggle the state of LED 0, repeatedly.
* Arguments   : pointer to task-specific data passed in during task create (not used in this case).
*********************************************************************************************************
*/
static void myTask1(void *pdata) {
  		INT8U retval;
  		pdata=pdata;         /* dummy usage to avoid compiler warning         */

      while (TRUE) {       /* Task body, ALWAYS written as an infinite loop */
      
        retval=OSTimeDlyHMSM(0,0,2,0);  /* Delay for hr,min,sec,ms          */
      
        PORTP ^= 0x01;     /* Toggle bit 0 (LED 0)                          */
      
        } /* end while */
} /* end myTask1()     */

/*
*********************************************************************************************************
*                                                main()
*
* Description : This is the standard entry point for C code.  It is assumed that your code will call
*               main() once you have performed all necessary 68HC12 and C initialization.
* Arguments   : none
*********************************************************************************************************
*/

void main(void) {
  INT8U retval;
  
/* Install uC/OS-II interrupt handlers into DBug12's vector table
 */
  *(void **)0x0b20 = OSTickISR;
  *(void **)0x0b36 = OSCtxSw;

/* set Port P as all outputs and initialized
 */
  DDRP  = 0xFF;
  PORTP = 0xFF;
    
/* set DDRCAN for bits 5:6 to be outputs
 */
	DDRCAN = 0x60;
 
/* set PORTCAN bit 6 to '0' (switches) and bit 5 to '1' (LEDs)
 */
	PORTCAN = 0x20;

  
  OSInit();       /* Initialize "uC/OS-II, The Real-Time Kernel"
                   */
	AppTickInit();  /* Special call to set up HC12 timer tick interrupt
		               * ( see Os_cfg.h and Os_cpu_c.c )
		               */

/* Insert here any other initialization code needed before starting multitasking
 * ...
 */
     
/* Create the first task.  Note that the stack pointer is the END of the buffer (builds DOWN)
 */
   retval=OSTaskCreate(myTask1,(void *)0,&taskstack1[TASK_STK_SIZE-1],0);

  OSStart();    /* Start multitasking (i.e. give control to uC/OS-II).
                 *
                 * No code after this point will be executed ( the OSStart()
                 * function does not ever return!).
                 */

}/* end of main() */

